# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sarus_data_spec/protobuf/transform.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sarus_data_spec.protobuf import type_pb2 as sarus__data__spec_dot_protobuf_dot_type__pb2
from sarus_data_spec.protobuf import path_pb2 as sarus__data__spec_dot_protobuf_dot_path__pb2
from sarus_data_spec.protobuf import scalar_pb2 as sarus__data__spec_dot_protobuf_dot_scalar__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sarus_data_spec/protobuf/transform.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(sarus_data_spec/protobuf/transform.proto\x1a#sarus_data_spec/protobuf/type.proto\x1a#sarus_data_spec/protobuf/path.proto\x1a%sarus_data_spec/protobuf/scalar.proto\"\xcd\x1f\n\tTransform\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03\x64oc\x18\x03 \x01(\t\x12\x1d\n\x04spec\x18\x04 \x01(\x0b\x32\x0f.Transform.Spec\x12.\n\nproperties\x18\x05 \x03(\x0b\x32\x1a.Transform.PropertiesEntry\x12\x12\n\ninversible\x18\x06 \x01(\x08\x12\x19\n\x11schema_preserving\x18\x07 \x01(\x08\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xfd\n\n\x04Spec\x12\'\n\x08identity\x18\x01 \x01(\x0b\x32\x13.Transform.IdentityH\x00\x12\'\n\x08variable\x18\x02 \x01(\x0b\x32\x13.Transform.VariableH\x00\x12\'\n\x08\x63omposed\x18\x03 \x01(\x0b\x32\x13.Transform.ComposedH\x00\x12%\n\x07project\x18\x04 \x01(\x0b\x32\x12.Transform.ProjectH\x00\x12#\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x11.Transform.FilterH\x00\x12%\n\x07shuffle\x18\x06 \x01(\x0b\x32\x12.Transform.ShuffleH\x00\x12\x1f\n\x04join\x18\x07 \x01(\x0b\x32\x0f.Transform.JoinH\x00\x12\x1f\n\x04\x63\x61st\x18\x08 \x01(\x0b\x32\x0f.Transform.CastH\x00\x12#\n\x06sample\x18\t \x01(\x0b\x32\x11.Transform.SampleH\x00\x12\x30\n\ruser_settings\x18\n \x01(\x0b\x32\x17.Transform.UserSettingsH\x00\x12-\n\x0fprotect_dataset\x18\x0b \x01(\x0b\x32\x12.Transform.ProtectH\x00\x12\'\n\x08\x65xternal\x18\x0c \x01(\x0b\x32\x13.Transform.ExternalH\x00\x12)\n\tsynthetic\x18\r \x01(\x0b\x32\x14.Transform.SyntheticH\x00\x12)\n\ttranscode\x18\x0e \x01(\x0b\x32\x14.Transform.TranscodeH\x00\x12\x38\n\x11inverse_transcode\x18\x0f \x01(\x0b\x32\x1b.Transform.InverseTranscodeH\x00\x12&\n\x08get_item\x18\x10 \x01(\x0b\x32\x12.Transform.GetItemH\x00\x12\x34\n\x0fprotected_paths\x18\x11 \x01(\x0b\x32\x19.Transform.ProtectedPathsH\x00\x12\x43\n\x17\x61utomatic_user_settings\x18\x12 \x01(\x0b\x32 .Transform.AutomaticUserSettingsH\x00\x12.\n\x0cpublic_paths\x18\x13 \x01(\x0b\x32\x16.Transform.PublicPathsH\x00\x12\x30\n\rassign_budget\x18\x14 \x01(\x0b\x32\x17.Transform.AssignBudgetH\x00\x12\x36\n\x10\x61utomatic_budget\x18\x15 \x01(\x0b\x32\x1a.Transform.AutomaticBudgetH\x00\x12\x37\n\x10\x61ttribute_budget\x18\x16 \x01(\x0b\x32\x1b.Transform.AttributesBudgetH\x00\x12(\n\tsd_budget\x18\x17 \x01(\x0b\x32\x13.Transform.SDBudgetH\x00\x12,\n\x0b\x64\x65rive_seed\x18\x18 \x01(\x0b\x32\x15.Transform.DeriveSeedH\x00\x12+\n\x0bgroup_by_pe\x18\x19 \x01(\x0b\x32\x14.Transform.GroupByPEH\x00\x12\x34\n\x0fsampling_ratios\x18\x1a \x01(\x0b\x32\x19.Transform.SamplingRatiosH\x00\x12*\n\nselect_sql\x18\x1b \x01(\x0b\x32\x14.Transform.SelectSqlH\x00\x12%\n\x07\x65xtract\x18\x1c \x01(\x0b\x32\x12.Transform.ExtractH\x00\x12\x38\n\x11relationship_spec\x18\x1d \x01(\x0b\x32\x1b.Transform.RelationshipSpecH\x00\x12@\n\x15\x64ifferentiated_sample\x18\x1e \x01(\x0b\x32\x1f.Transform.DifferentiatedSampleH\x00\x42\x06\n\x04spec\x1a\xa1\x06\n\x08\x45xternal\x12\x11\n\targuments\x18\x01 \x01(\x0c\x12\x17\n\x0fnamed_arguments\x18\x02 \x01(\x0c\x12\x37\n\rop_identifier\x18\x03 \x01(\x0b\x32 .Transform.External.OpIdentifier\x1a\xcb\x03\n\x0cOpIdentifier\x12&\n\x03std\x18\x01 \x01(\x0b\x32\x17.Transform.External.StdH\x00\x12,\n\x06pandas\x18\x02 \x01(\x0b\x32\x1a.Transform.External.PandasH\x00\x12*\n\x05numpy\x18\x03 \x01(\x0b\x32\x19.Transform.External.NumpyH\x00\x12\x34\n\ntensorflow\x18\x04 \x01(\x0b\x32\x1e.Transform.External.TensorflowH\x00\x12.\n\x07sklearn\x18\x05 \x01(\x0b\x32\x1b.Transform.External.SklearnH\x00\x12?\n\x10pandas_profiling\x18\x06 \x01(\x0b\x32#.Transform.External.PandasProfilingH\x00\x12.\n\x07xgboost\x18\x07 \x01(\x0b\x32\x1b.Transform.External.XGBoostH\x00\x12*\n\x05skopt\x18\x08 \x01(\x0b\x32\x19.Transform.External.SkoptH\x00\x12\x30\n\x08imblearn\x18\t \x01(\x0b\x32\x1c.Transform.External.ImblearnH\x00\x42\x04\n\x02op\x1a\x13\n\x03Std\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\x16\n\x06Pandas\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\x15\n\x05Numpy\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\x1a\n\nTensorflow\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\x17\n\x07Sklearn\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\x1f\n\x0fPandasProfiling\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\x17\n\x07XGBoost\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\x15\n\x05Skopt\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\x18\n\x08Imblearn\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\n\n\x08Identity\x1a*\n\x08Variable\x12\x10\n\x08position\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a\xa9\x01\n\x08\x43omposed\x12\x11\n\ttransform\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x03(\t\x12@\n\x0fnamed_arguments\x18\x03 \x03(\x0b\x32\'.Transform.Composed.NamedArgumentsEntry\x1a\x35\n\x13NamedArgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x34\n\x07Project\x12)\n\nprojection\x18\x01 \x01(\x0b\x32\x15.sarus_data_spec.Type\x1a/\n\x06\x46ilter\x12%\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x15.sarus_data_spec.Type\x1a\t\n\x07Shuffle\x1a)\n\x04Join\x12!\n\x02on\x18\x01 \x01(\x0b\x32\x15.sarus_data_spec.Type\x1a+\n\x04\x43\x61st\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x15.sarus_data_spec.Type\x1a\x61\n\x06Sample\x12\x12\n\x08\x66raction\x18\x01 \x01(\x01H\x00\x12\x0e\n\x04size\x18\x02 \x01(\x03H\x00\x12%\n\x04seed\x18\x03 \x01(\x0b\x32\x17.sarus_data_spec.ScalarB\x0c\n\nproportion\x1av\n\x0fSchemaInference\x12:\n\x0b\x63\x61st_policy\x18\x01 \x01(\x0e\x32%.Transform.SchemaInference.CastPolicy\"\'\n\nCastPolicy\x12\x08\n\x04NONE\x10\x00\x12\x0f\n\x0bMOST_LIKELY\x10\x01\x1a\x16\n\x07GroupBy\x12\x0b\n\x03key\x18\x01 \x01(\t\x1a\x0b\n\tSynthetic\x1a\x0e\n\x0cUserSettings\x1a/\n\x15\x41utomaticUserSettings\x12\x16\n\x0emax_categories\x18\x01 \x01(\x03\x1a\t\n\x07Protect\x1a\x0b\n\tTranscode\x1a\x12\n\x10InverseTranscode\x1ao\n\x14\x44ifferentiatedSample\x12\x12\n\x08\x66raction\x18\x01 \x01(\x01H\x00\x12\x0e\n\x04size\x18\x02 \x01(\x03H\x00\x12%\n\x04seed\x18\x03 \x01(\x0b\x32\x17.sarus_data_spec.ScalarB\x0c\n\nproportion\x1a\x10\n\x0eProtectedPaths\x1a\r\n\x0bPublicPaths\x1a.\n\x07GetItem\x12#\n\x04path\x18\x01 \x01(\x0b\x32\x15.sarus_data_spec.Path\x1a\x0e\n\x0c\x41ssignBudget\x1a\x11\n\x0f\x41utomaticBudget\x1a\x12\n\x10\x41ttributesBudget\x1a\n\n\x08SDBudget\x1a$\n\nDeriveSeed\x12\x16\n\x0erandom_integer\x18\x01 \x01(\x03\x1a\x0b\n\tGroupByPE\x1a\x10\n\x0eSamplingRatios\x1a\x12\n\x10RelationshipSpec\x1a\xaf\x03\n\tSelectSql\x12\x0f\n\x05query\x18\x01 \x01(\tH\x00\x12>\n\x0f\x61liased_queries\x18\x02 \x01(\x0b\x32#.Transform.SelectSql.AliasedQueriesH\x00\x12\x34\n\x0bsql_dialect\x18\x03 \x01(\x0e\x32\x1f.Transform.SelectSql.SQLDialect\x1aJ\n\x0e\x41liasedQueries\x12\x38\n\raliased_query\x18\x01 \x03(\x0b\x32!.Transform.SelectSql.AliasedQuery\x1a\x42\n\x0c\x41liasedQuery\x12#\n\x04path\x18\x01 \x01(\x0b\x32\x15.sarus_data_spec.Path\x12\r\n\x05query\x18\x02 \x01(\t\"\x80\x01\n\nSQLDialect\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08POSTGRES\x10\x01\x12\x0e\n\nSQL_SERVER\x10\x02\x12\n\n\x06MY_SQL\x10\x03\x12\x0b\n\x07SQLLITE\x10\x04\x12\n\n\x06ORACLE\x10\x05\x12\r\n\tBIG_QUERY\x10\x06\x12\x0c\n\x08REDSHIFT\x10\x07\x12\x08\n\x04HIVE\x10\x08\x42\x08\n\x06select\x1a\x17\n\x07\x45xtract\x12\x0c\n\x04size\x18\x01 \x01(\x05\x62\x06proto3'
  ,
  dependencies=[sarus__data__spec_dot_protobuf_dot_type__pb2.DESCRIPTOR,sarus__data__spec_dot_protobuf_dot_path__pb2.DESCRIPTOR,sarus__data__spec_dot_protobuf_dot_scalar__pb2.DESCRIPTOR,])



_TRANSFORM_SCHEMAINFERENCE_CASTPOLICY = _descriptor.EnumDescriptor(
  name='CastPolicy',
  full_name='Transform.SchemaInference.CastPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOST_LIKELY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3209,
  serialized_end=3248,
)
_sym_db.RegisterEnumDescriptor(_TRANSFORM_SCHEMAINFERENCE_CASTPOLICY)

_TRANSFORM_SELECTSQL_SQLDIALECT = _descriptor.EnumDescriptor(
  name='SQLDialect',
  full_name='Transform.SelectSql.SQLDialect',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POSTGRES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SQL_SERVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MY_SQL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SQLLITE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORACLE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BIG_QUERY', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REDSHIFT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIVE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4040,
  serialized_end=4168,
)
_sym_db.RegisterEnumDescriptor(_TRANSFORM_SELECTSQL_SQLDIALECT)


_TRANSFORM_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='Transform.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Transform.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Transform.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=387,
)

_TRANSFORM_SPEC = _descriptor.Descriptor(
  name='Spec',
  full_name='Transform.Spec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identity', full_name='Transform.Spec.identity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable', full_name='Transform.Spec.variable', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='composed', full_name='Transform.Spec.composed', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project', full_name='Transform.Spec.project', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='Transform.Spec.filter', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shuffle', full_name='Transform.Spec.shuffle', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join', full_name='Transform.Spec.join', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cast', full_name='Transform.Spec.cast', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample', full_name='Transform.Spec.sample', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_settings', full_name='Transform.Spec.user_settings', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protect_dataset', full_name='Transform.Spec.protect_dataset', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external', full_name='Transform.Spec.external', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='synthetic', full_name='Transform.Spec.synthetic', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transcode', full_name='Transform.Spec.transcode', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inverse_transcode', full_name='Transform.Spec.inverse_transcode', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_item', full_name='Transform.Spec.get_item', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protected_paths', full_name='Transform.Spec.protected_paths', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automatic_user_settings', full_name='Transform.Spec.automatic_user_settings', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_paths', full_name='Transform.Spec.public_paths', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assign_budget', full_name='Transform.Spec.assign_budget', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automatic_budget', full_name='Transform.Spec.automatic_budget', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attribute_budget', full_name='Transform.Spec.attribute_budget', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sd_budget', full_name='Transform.Spec.sd_budget', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derive_seed', full_name='Transform.Spec.derive_seed', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_by_pe', full_name='Transform.Spec.group_by_pe', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling_ratios', full_name='Transform.Spec.sampling_ratios', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='select_sql', full_name='Transform.Spec.select_sql', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extract', full_name='Transform.Spec.extract', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relationship_spec', full_name='Transform.Spec.relationship_spec', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='differentiated_sample', full_name='Transform.Spec.differentiated_sample', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='Transform.Spec.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=390,
  serialized_end=1795,
)

_TRANSFORM_EXTERNAL_OPIDENTIFIER = _descriptor.Descriptor(
  name='OpIdentifier',
  full_name='Transform.External.OpIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='std', full_name='Transform.External.OpIdentifier.std', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pandas', full_name='Transform.External.OpIdentifier.pandas', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numpy', full_name='Transform.External.OpIdentifier.numpy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tensorflow', full_name='Transform.External.OpIdentifier.tensorflow', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sklearn', full_name='Transform.External.OpIdentifier.sklearn', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pandas_profiling', full_name='Transform.External.OpIdentifier.pandas_profiling', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xgboost', full_name='Transform.External.OpIdentifier.xgboost', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skopt', full_name='Transform.External.OpIdentifier.skopt', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imblearn', full_name='Transform.External.OpIdentifier.imblearn', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='op', full_name='Transform.External.OpIdentifier.op',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1912,
  serialized_end=2371,
)

_TRANSFORM_EXTERNAL_STD = _descriptor.Descriptor(
  name='Std',
  full_name='Transform.External.Std',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Transform.External.Std.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2373,
  serialized_end=2392,
)

_TRANSFORM_EXTERNAL_PANDAS = _descriptor.Descriptor(
  name='Pandas',
  full_name='Transform.External.Pandas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Transform.External.Pandas.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2394,
  serialized_end=2416,
)

_TRANSFORM_EXTERNAL_NUMPY = _descriptor.Descriptor(
  name='Numpy',
  full_name='Transform.External.Numpy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Transform.External.Numpy.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2418,
  serialized_end=2439,
)

_TRANSFORM_EXTERNAL_TENSORFLOW = _descriptor.Descriptor(
  name='Tensorflow',
  full_name='Transform.External.Tensorflow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Transform.External.Tensorflow.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2441,
  serialized_end=2467,
)

_TRANSFORM_EXTERNAL_SKLEARN = _descriptor.Descriptor(
  name='Sklearn',
  full_name='Transform.External.Sklearn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Transform.External.Sklearn.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2469,
  serialized_end=2492,
)

_TRANSFORM_EXTERNAL_PANDASPROFILING = _descriptor.Descriptor(
  name='PandasProfiling',
  full_name='Transform.External.PandasProfiling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Transform.External.PandasProfiling.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2494,
  serialized_end=2525,
)

_TRANSFORM_EXTERNAL_XGBOOST = _descriptor.Descriptor(
  name='XGBoost',
  full_name='Transform.External.XGBoost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Transform.External.XGBoost.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2527,
  serialized_end=2550,
)

_TRANSFORM_EXTERNAL_SKOPT = _descriptor.Descriptor(
  name='Skopt',
  full_name='Transform.External.Skopt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Transform.External.Skopt.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2552,
  serialized_end=2573,
)

_TRANSFORM_EXTERNAL_IMBLEARN = _descriptor.Descriptor(
  name='Imblearn',
  full_name='Transform.External.Imblearn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Transform.External.Imblearn.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2575,
  serialized_end=2599,
)

_TRANSFORM_EXTERNAL = _descriptor.Descriptor(
  name='External',
  full_name='Transform.External',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='arguments', full_name='Transform.External.arguments', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='named_arguments', full_name='Transform.External.named_arguments', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='op_identifier', full_name='Transform.External.op_identifier', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRANSFORM_EXTERNAL_OPIDENTIFIER, _TRANSFORM_EXTERNAL_STD, _TRANSFORM_EXTERNAL_PANDAS, _TRANSFORM_EXTERNAL_NUMPY, _TRANSFORM_EXTERNAL_TENSORFLOW, _TRANSFORM_EXTERNAL_SKLEARN, _TRANSFORM_EXTERNAL_PANDASPROFILING, _TRANSFORM_EXTERNAL_XGBOOST, _TRANSFORM_EXTERNAL_SKOPT, _TRANSFORM_EXTERNAL_IMBLEARN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1798,
  serialized_end=2599,
)

_TRANSFORM_IDENTITY = _descriptor.Descriptor(
  name='Identity',
  full_name='Transform.Identity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2601,
  serialized_end=2611,
)

_TRANSFORM_VARIABLE = _descriptor.Descriptor(
  name='Variable',
  full_name='Transform.Variable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='Transform.Variable.position', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Transform.Variable.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2613,
  serialized_end=2655,
)

_TRANSFORM_COMPOSED_NAMEDARGUMENTSENTRY = _descriptor.Descriptor(
  name='NamedArgumentsEntry',
  full_name='Transform.Composed.NamedArgumentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Transform.Composed.NamedArgumentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Transform.Composed.NamedArgumentsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2774,
  serialized_end=2827,
)

_TRANSFORM_COMPOSED = _descriptor.Descriptor(
  name='Composed',
  full_name='Transform.Composed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transform', full_name='Transform.Composed.transform', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='Transform.Composed.arguments', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='named_arguments', full_name='Transform.Composed.named_arguments', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRANSFORM_COMPOSED_NAMEDARGUMENTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2658,
  serialized_end=2827,
)

_TRANSFORM_PROJECT = _descriptor.Descriptor(
  name='Project',
  full_name='Transform.Project',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='projection', full_name='Transform.Project.projection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2829,
  serialized_end=2881,
)

_TRANSFORM_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='Transform.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='Transform.Filter.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2883,
  serialized_end=2930,
)

_TRANSFORM_SHUFFLE = _descriptor.Descriptor(
  name='Shuffle',
  full_name='Transform.Shuffle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2932,
  serialized_end=2941,
)

_TRANSFORM_JOIN = _descriptor.Descriptor(
  name='Join',
  full_name='Transform.Join',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='on', full_name='Transform.Join.on', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2943,
  serialized_end=2984,
)

_TRANSFORM_CAST = _descriptor.Descriptor(
  name='Cast',
  full_name='Transform.Cast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='Transform.Cast.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2986,
  serialized_end=3029,
)

_TRANSFORM_SAMPLE = _descriptor.Descriptor(
  name='Sample',
  full_name='Transform.Sample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fraction', full_name='Transform.Sample.fraction', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='Transform.Sample.size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seed', full_name='Transform.Sample.seed', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='proportion', full_name='Transform.Sample.proportion',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3031,
  serialized_end=3128,
)

_TRANSFORM_SCHEMAINFERENCE = _descriptor.Descriptor(
  name='SchemaInference',
  full_name='Transform.SchemaInference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cast_policy', full_name='Transform.SchemaInference.cast_policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRANSFORM_SCHEMAINFERENCE_CASTPOLICY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3130,
  serialized_end=3248,
)

_TRANSFORM_GROUPBY = _descriptor.Descriptor(
  name='GroupBy',
  full_name='Transform.GroupBy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Transform.GroupBy.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3250,
  serialized_end=3272,
)

_TRANSFORM_SYNTHETIC = _descriptor.Descriptor(
  name='Synthetic',
  full_name='Transform.Synthetic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3274,
  serialized_end=3285,
)

_TRANSFORM_USERSETTINGS = _descriptor.Descriptor(
  name='UserSettings',
  full_name='Transform.UserSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3287,
  serialized_end=3301,
)

_TRANSFORM_AUTOMATICUSERSETTINGS = _descriptor.Descriptor(
  name='AutomaticUserSettings',
  full_name='Transform.AutomaticUserSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_categories', full_name='Transform.AutomaticUserSettings.max_categories', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3303,
  serialized_end=3350,
)

_TRANSFORM_PROTECT = _descriptor.Descriptor(
  name='Protect',
  full_name='Transform.Protect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3352,
  serialized_end=3361,
)

_TRANSFORM_TRANSCODE = _descriptor.Descriptor(
  name='Transcode',
  full_name='Transform.Transcode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3363,
  serialized_end=3374,
)

_TRANSFORM_INVERSETRANSCODE = _descriptor.Descriptor(
  name='InverseTranscode',
  full_name='Transform.InverseTranscode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3376,
  serialized_end=3394,
)

_TRANSFORM_DIFFERENTIATEDSAMPLE = _descriptor.Descriptor(
  name='DifferentiatedSample',
  full_name='Transform.DifferentiatedSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fraction', full_name='Transform.DifferentiatedSample.fraction', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='Transform.DifferentiatedSample.size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seed', full_name='Transform.DifferentiatedSample.seed', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='proportion', full_name='Transform.DifferentiatedSample.proportion',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3396,
  serialized_end=3507,
)

_TRANSFORM_PROTECTEDPATHS = _descriptor.Descriptor(
  name='ProtectedPaths',
  full_name='Transform.ProtectedPaths',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3509,
  serialized_end=3525,
)

_TRANSFORM_PUBLICPATHS = _descriptor.Descriptor(
  name='PublicPaths',
  full_name='Transform.PublicPaths',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3527,
  serialized_end=3540,
)

_TRANSFORM_GETITEM = _descriptor.Descriptor(
  name='GetItem',
  full_name='Transform.GetItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Transform.GetItem.path', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3542,
  serialized_end=3588,
)

_TRANSFORM_ASSIGNBUDGET = _descriptor.Descriptor(
  name='AssignBudget',
  full_name='Transform.AssignBudget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3590,
  serialized_end=3604,
)

_TRANSFORM_AUTOMATICBUDGET = _descriptor.Descriptor(
  name='AutomaticBudget',
  full_name='Transform.AutomaticBudget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3606,
  serialized_end=3623,
)

_TRANSFORM_ATTRIBUTESBUDGET = _descriptor.Descriptor(
  name='AttributesBudget',
  full_name='Transform.AttributesBudget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3625,
  serialized_end=3643,
)

_TRANSFORM_SDBUDGET = _descriptor.Descriptor(
  name='SDBudget',
  full_name='Transform.SDBudget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3645,
  serialized_end=3655,
)

_TRANSFORM_DERIVESEED = _descriptor.Descriptor(
  name='DeriveSeed',
  full_name='Transform.DeriveSeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='random_integer', full_name='Transform.DeriveSeed.random_integer', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3657,
  serialized_end=3693,
)

_TRANSFORM_GROUPBYPE = _descriptor.Descriptor(
  name='GroupByPE',
  full_name='Transform.GroupByPE',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3695,
  serialized_end=3706,
)

_TRANSFORM_SAMPLINGRATIOS = _descriptor.Descriptor(
  name='SamplingRatios',
  full_name='Transform.SamplingRatios',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3708,
  serialized_end=3724,
)

_TRANSFORM_RELATIONSHIPSPEC = _descriptor.Descriptor(
  name='RelationshipSpec',
  full_name='Transform.RelationshipSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3726,
  serialized_end=3744,
)

_TRANSFORM_SELECTSQL_ALIASEDQUERIES = _descriptor.Descriptor(
  name='AliasedQueries',
  full_name='Transform.SelectSql.AliasedQueries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aliased_query', full_name='Transform.SelectSql.AliasedQueries.aliased_query', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3895,
  serialized_end=3969,
)

_TRANSFORM_SELECTSQL_ALIASEDQUERY = _descriptor.Descriptor(
  name='AliasedQuery',
  full_name='Transform.SelectSql.AliasedQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Transform.SelectSql.AliasedQuery.path', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='Transform.SelectSql.AliasedQuery.query', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3971,
  serialized_end=4037,
)

_TRANSFORM_SELECTSQL = _descriptor.Descriptor(
  name='SelectSql',
  full_name='Transform.SelectSql',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='Transform.SelectSql.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aliased_queries', full_name='Transform.SelectSql.aliased_queries', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sql_dialect', full_name='Transform.SelectSql.sql_dialect', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRANSFORM_SELECTSQL_ALIASEDQUERIES, _TRANSFORM_SELECTSQL_ALIASEDQUERY, ],
  enum_types=[
    _TRANSFORM_SELECTSQL_SQLDIALECT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='select', full_name='Transform.SelectSql.select',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3747,
  serialized_end=4178,
)

_TRANSFORM_EXTRACT = _descriptor.Descriptor(
  name='Extract',
  full_name='Transform.Extract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='Transform.Extract.size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4180,
  serialized_end=4203,
)

_TRANSFORM = _descriptor.Descriptor(
  name='Transform',
  full_name='Transform',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='Transform.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Transform.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doc', full_name='Transform.doc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='Transform.spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='Transform.properties', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inversible', full_name='Transform.inversible', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_preserving', full_name='Transform.schema_preserving', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRANSFORM_PROPERTIESENTRY, _TRANSFORM_SPEC, _TRANSFORM_EXTERNAL, _TRANSFORM_IDENTITY, _TRANSFORM_VARIABLE, _TRANSFORM_COMPOSED, _TRANSFORM_PROJECT, _TRANSFORM_FILTER, _TRANSFORM_SHUFFLE, _TRANSFORM_JOIN, _TRANSFORM_CAST, _TRANSFORM_SAMPLE, _TRANSFORM_SCHEMAINFERENCE, _TRANSFORM_GROUPBY, _TRANSFORM_SYNTHETIC, _TRANSFORM_USERSETTINGS, _TRANSFORM_AUTOMATICUSERSETTINGS, _TRANSFORM_PROTECT, _TRANSFORM_TRANSCODE, _TRANSFORM_INVERSETRANSCODE, _TRANSFORM_DIFFERENTIATEDSAMPLE, _TRANSFORM_PROTECTEDPATHS, _TRANSFORM_PUBLICPATHS, _TRANSFORM_GETITEM, _TRANSFORM_ASSIGNBUDGET, _TRANSFORM_AUTOMATICBUDGET, _TRANSFORM_ATTRIBUTESBUDGET, _TRANSFORM_SDBUDGET, _TRANSFORM_DERIVESEED, _TRANSFORM_GROUPBYPE, _TRANSFORM_SAMPLINGRATIOS, _TRANSFORM_RELATIONSHIPSPEC, _TRANSFORM_SELECTSQL, _TRANSFORM_EXTRACT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=4203,
)

_TRANSFORM_PROPERTIESENTRY.containing_type = _TRANSFORM
_TRANSFORM_SPEC.fields_by_name['identity'].message_type = _TRANSFORM_IDENTITY
_TRANSFORM_SPEC.fields_by_name['variable'].message_type = _TRANSFORM_VARIABLE
_TRANSFORM_SPEC.fields_by_name['composed'].message_type = _TRANSFORM_COMPOSED
_TRANSFORM_SPEC.fields_by_name['project'].message_type = _TRANSFORM_PROJECT
_TRANSFORM_SPEC.fields_by_name['filter'].message_type = _TRANSFORM_FILTER
_TRANSFORM_SPEC.fields_by_name['shuffle'].message_type = _TRANSFORM_SHUFFLE
_TRANSFORM_SPEC.fields_by_name['join'].message_type = _TRANSFORM_JOIN
_TRANSFORM_SPEC.fields_by_name['cast'].message_type = _TRANSFORM_CAST
_TRANSFORM_SPEC.fields_by_name['sample'].message_type = _TRANSFORM_SAMPLE
_TRANSFORM_SPEC.fields_by_name['user_settings'].message_type = _TRANSFORM_USERSETTINGS
_TRANSFORM_SPEC.fields_by_name['protect_dataset'].message_type = _TRANSFORM_PROTECT
_TRANSFORM_SPEC.fields_by_name['external'].message_type = _TRANSFORM_EXTERNAL
_TRANSFORM_SPEC.fields_by_name['synthetic'].message_type = _TRANSFORM_SYNTHETIC
_TRANSFORM_SPEC.fields_by_name['transcode'].message_type = _TRANSFORM_TRANSCODE
_TRANSFORM_SPEC.fields_by_name['inverse_transcode'].message_type = _TRANSFORM_INVERSETRANSCODE
_TRANSFORM_SPEC.fields_by_name['get_item'].message_type = _TRANSFORM_GETITEM
_TRANSFORM_SPEC.fields_by_name['protected_paths'].message_type = _TRANSFORM_PROTECTEDPATHS
_TRANSFORM_SPEC.fields_by_name['automatic_user_settings'].message_type = _TRANSFORM_AUTOMATICUSERSETTINGS
_TRANSFORM_SPEC.fields_by_name['public_paths'].message_type = _TRANSFORM_PUBLICPATHS
_TRANSFORM_SPEC.fields_by_name['assign_budget'].message_type = _TRANSFORM_ASSIGNBUDGET
_TRANSFORM_SPEC.fields_by_name['automatic_budget'].message_type = _TRANSFORM_AUTOMATICBUDGET
_TRANSFORM_SPEC.fields_by_name['attribute_budget'].message_type = _TRANSFORM_ATTRIBUTESBUDGET
_TRANSFORM_SPEC.fields_by_name['sd_budget'].message_type = _TRANSFORM_SDBUDGET
_TRANSFORM_SPEC.fields_by_name['derive_seed'].message_type = _TRANSFORM_DERIVESEED
_TRANSFORM_SPEC.fields_by_name['group_by_pe'].message_type = _TRANSFORM_GROUPBYPE
_TRANSFORM_SPEC.fields_by_name['sampling_ratios'].message_type = _TRANSFORM_SAMPLINGRATIOS
_TRANSFORM_SPEC.fields_by_name['select_sql'].message_type = _TRANSFORM_SELECTSQL
_TRANSFORM_SPEC.fields_by_name['extract'].message_type = _TRANSFORM_EXTRACT
_TRANSFORM_SPEC.fields_by_name['relationship_spec'].message_type = _TRANSFORM_RELATIONSHIPSPEC
_TRANSFORM_SPEC.fields_by_name['differentiated_sample'].message_type = _TRANSFORM_DIFFERENTIATEDSAMPLE
_TRANSFORM_SPEC.containing_type = _TRANSFORM
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['identity'])
_TRANSFORM_SPEC.fields_by_name['identity'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['variable'])
_TRANSFORM_SPEC.fields_by_name['variable'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['composed'])
_TRANSFORM_SPEC.fields_by_name['composed'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['project'])
_TRANSFORM_SPEC.fields_by_name['project'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['filter'])
_TRANSFORM_SPEC.fields_by_name['filter'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['shuffle'])
_TRANSFORM_SPEC.fields_by_name['shuffle'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['join'])
_TRANSFORM_SPEC.fields_by_name['join'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['cast'])
_TRANSFORM_SPEC.fields_by_name['cast'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['sample'])
_TRANSFORM_SPEC.fields_by_name['sample'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['user_settings'])
_TRANSFORM_SPEC.fields_by_name['user_settings'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['protect_dataset'])
_TRANSFORM_SPEC.fields_by_name['protect_dataset'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['external'])
_TRANSFORM_SPEC.fields_by_name['external'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['synthetic'])
_TRANSFORM_SPEC.fields_by_name['synthetic'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['transcode'])
_TRANSFORM_SPEC.fields_by_name['transcode'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['inverse_transcode'])
_TRANSFORM_SPEC.fields_by_name['inverse_transcode'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['get_item'])
_TRANSFORM_SPEC.fields_by_name['get_item'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['protected_paths'])
_TRANSFORM_SPEC.fields_by_name['protected_paths'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['automatic_user_settings'])
_TRANSFORM_SPEC.fields_by_name['automatic_user_settings'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['public_paths'])
_TRANSFORM_SPEC.fields_by_name['public_paths'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['assign_budget'])
_TRANSFORM_SPEC.fields_by_name['assign_budget'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['automatic_budget'])
_TRANSFORM_SPEC.fields_by_name['automatic_budget'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['attribute_budget'])
_TRANSFORM_SPEC.fields_by_name['attribute_budget'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['sd_budget'])
_TRANSFORM_SPEC.fields_by_name['sd_budget'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['derive_seed'])
_TRANSFORM_SPEC.fields_by_name['derive_seed'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['group_by_pe'])
_TRANSFORM_SPEC.fields_by_name['group_by_pe'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['sampling_ratios'])
_TRANSFORM_SPEC.fields_by_name['sampling_ratios'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['select_sql'])
_TRANSFORM_SPEC.fields_by_name['select_sql'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['extract'])
_TRANSFORM_SPEC.fields_by_name['extract'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['relationship_spec'])
_TRANSFORM_SPEC.fields_by_name['relationship_spec'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_SPEC.oneofs_by_name['spec'].fields.append(
  _TRANSFORM_SPEC.fields_by_name['differentiated_sample'])
_TRANSFORM_SPEC.fields_by_name['differentiated_sample'].containing_oneof = _TRANSFORM_SPEC.oneofs_by_name['spec']
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['std'].message_type = _TRANSFORM_EXTERNAL_STD
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['pandas'].message_type = _TRANSFORM_EXTERNAL_PANDAS
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['numpy'].message_type = _TRANSFORM_EXTERNAL_NUMPY
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['tensorflow'].message_type = _TRANSFORM_EXTERNAL_TENSORFLOW
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['sklearn'].message_type = _TRANSFORM_EXTERNAL_SKLEARN
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['pandas_profiling'].message_type = _TRANSFORM_EXTERNAL_PANDASPROFILING
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['xgboost'].message_type = _TRANSFORM_EXTERNAL_XGBOOST
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['skopt'].message_type = _TRANSFORM_EXTERNAL_SKOPT
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['imblearn'].message_type = _TRANSFORM_EXTERNAL_IMBLEARN
_TRANSFORM_EXTERNAL_OPIDENTIFIER.containing_type = _TRANSFORM_EXTERNAL
_TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op'].fields.append(
  _TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['std'])
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['std'].containing_oneof = _TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op']
_TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op'].fields.append(
  _TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['pandas'])
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['pandas'].containing_oneof = _TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op']
_TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op'].fields.append(
  _TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['numpy'])
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['numpy'].containing_oneof = _TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op']
_TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op'].fields.append(
  _TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['tensorflow'])
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['tensorflow'].containing_oneof = _TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op']
_TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op'].fields.append(
  _TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['sklearn'])
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['sklearn'].containing_oneof = _TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op']
_TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op'].fields.append(
  _TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['pandas_profiling'])
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['pandas_profiling'].containing_oneof = _TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op']
_TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op'].fields.append(
  _TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['xgboost'])
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['xgboost'].containing_oneof = _TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op']
_TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op'].fields.append(
  _TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['skopt'])
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['skopt'].containing_oneof = _TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op']
_TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op'].fields.append(
  _TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['imblearn'])
_TRANSFORM_EXTERNAL_OPIDENTIFIER.fields_by_name['imblearn'].containing_oneof = _TRANSFORM_EXTERNAL_OPIDENTIFIER.oneofs_by_name['op']
_TRANSFORM_EXTERNAL_STD.containing_type = _TRANSFORM_EXTERNAL
_TRANSFORM_EXTERNAL_PANDAS.containing_type = _TRANSFORM_EXTERNAL
_TRANSFORM_EXTERNAL_NUMPY.containing_type = _TRANSFORM_EXTERNAL
_TRANSFORM_EXTERNAL_TENSORFLOW.containing_type = _TRANSFORM_EXTERNAL
_TRANSFORM_EXTERNAL_SKLEARN.containing_type = _TRANSFORM_EXTERNAL
_TRANSFORM_EXTERNAL_PANDASPROFILING.containing_type = _TRANSFORM_EXTERNAL
_TRANSFORM_EXTERNAL_XGBOOST.containing_type = _TRANSFORM_EXTERNAL
_TRANSFORM_EXTERNAL_SKOPT.containing_type = _TRANSFORM_EXTERNAL
_TRANSFORM_EXTERNAL_IMBLEARN.containing_type = _TRANSFORM_EXTERNAL
_TRANSFORM_EXTERNAL.fields_by_name['op_identifier'].message_type = _TRANSFORM_EXTERNAL_OPIDENTIFIER
_TRANSFORM_EXTERNAL.containing_type = _TRANSFORM
_TRANSFORM_IDENTITY.containing_type = _TRANSFORM
_TRANSFORM_VARIABLE.containing_type = _TRANSFORM
_TRANSFORM_COMPOSED_NAMEDARGUMENTSENTRY.containing_type = _TRANSFORM_COMPOSED
_TRANSFORM_COMPOSED.fields_by_name['named_arguments'].message_type = _TRANSFORM_COMPOSED_NAMEDARGUMENTSENTRY
_TRANSFORM_COMPOSED.containing_type = _TRANSFORM
_TRANSFORM_PROJECT.fields_by_name['projection'].message_type = sarus__data__spec_dot_protobuf_dot_type__pb2._TYPE
_TRANSFORM_PROJECT.containing_type = _TRANSFORM
_TRANSFORM_FILTER.fields_by_name['filter'].message_type = sarus__data__spec_dot_protobuf_dot_type__pb2._TYPE
_TRANSFORM_FILTER.containing_type = _TRANSFORM
_TRANSFORM_SHUFFLE.containing_type = _TRANSFORM
_TRANSFORM_JOIN.fields_by_name['on'].message_type = sarus__data__spec_dot_protobuf_dot_type__pb2._TYPE
_TRANSFORM_JOIN.containing_type = _TRANSFORM
_TRANSFORM_CAST.fields_by_name['type'].message_type = sarus__data__spec_dot_protobuf_dot_type__pb2._TYPE
_TRANSFORM_CAST.containing_type = _TRANSFORM
_TRANSFORM_SAMPLE.fields_by_name['seed'].message_type = sarus__data__spec_dot_protobuf_dot_scalar__pb2._SCALAR
_TRANSFORM_SAMPLE.containing_type = _TRANSFORM
_TRANSFORM_SAMPLE.oneofs_by_name['proportion'].fields.append(
  _TRANSFORM_SAMPLE.fields_by_name['fraction'])
_TRANSFORM_SAMPLE.fields_by_name['fraction'].containing_oneof = _TRANSFORM_SAMPLE.oneofs_by_name['proportion']
_TRANSFORM_SAMPLE.oneofs_by_name['proportion'].fields.append(
  _TRANSFORM_SAMPLE.fields_by_name['size'])
_TRANSFORM_SAMPLE.fields_by_name['size'].containing_oneof = _TRANSFORM_SAMPLE.oneofs_by_name['proportion']
_TRANSFORM_SCHEMAINFERENCE.fields_by_name['cast_policy'].enum_type = _TRANSFORM_SCHEMAINFERENCE_CASTPOLICY
_TRANSFORM_SCHEMAINFERENCE.containing_type = _TRANSFORM
_TRANSFORM_SCHEMAINFERENCE_CASTPOLICY.containing_type = _TRANSFORM_SCHEMAINFERENCE
_TRANSFORM_GROUPBY.containing_type = _TRANSFORM
_TRANSFORM_SYNTHETIC.containing_type = _TRANSFORM
_TRANSFORM_USERSETTINGS.containing_type = _TRANSFORM
_TRANSFORM_AUTOMATICUSERSETTINGS.containing_type = _TRANSFORM
_TRANSFORM_PROTECT.containing_type = _TRANSFORM
_TRANSFORM_TRANSCODE.containing_type = _TRANSFORM
_TRANSFORM_INVERSETRANSCODE.containing_type = _TRANSFORM
_TRANSFORM_DIFFERENTIATEDSAMPLE.fields_by_name['seed'].message_type = sarus__data__spec_dot_protobuf_dot_scalar__pb2._SCALAR
_TRANSFORM_DIFFERENTIATEDSAMPLE.containing_type = _TRANSFORM
_TRANSFORM_DIFFERENTIATEDSAMPLE.oneofs_by_name['proportion'].fields.append(
  _TRANSFORM_DIFFERENTIATEDSAMPLE.fields_by_name['fraction'])
_TRANSFORM_DIFFERENTIATEDSAMPLE.fields_by_name['fraction'].containing_oneof = _TRANSFORM_DIFFERENTIATEDSAMPLE.oneofs_by_name['proportion']
_TRANSFORM_DIFFERENTIATEDSAMPLE.oneofs_by_name['proportion'].fields.append(
  _TRANSFORM_DIFFERENTIATEDSAMPLE.fields_by_name['size'])
_TRANSFORM_DIFFERENTIATEDSAMPLE.fields_by_name['size'].containing_oneof = _TRANSFORM_DIFFERENTIATEDSAMPLE.oneofs_by_name['proportion']
_TRANSFORM_PROTECTEDPATHS.containing_type = _TRANSFORM
_TRANSFORM_PUBLICPATHS.containing_type = _TRANSFORM
_TRANSFORM_GETITEM.fields_by_name['path'].message_type = sarus__data__spec_dot_protobuf_dot_path__pb2._PATH
_TRANSFORM_GETITEM.containing_type = _TRANSFORM
_TRANSFORM_ASSIGNBUDGET.containing_type = _TRANSFORM
_TRANSFORM_AUTOMATICBUDGET.containing_type = _TRANSFORM
_TRANSFORM_ATTRIBUTESBUDGET.containing_type = _TRANSFORM
_TRANSFORM_SDBUDGET.containing_type = _TRANSFORM
_TRANSFORM_DERIVESEED.containing_type = _TRANSFORM
_TRANSFORM_GROUPBYPE.containing_type = _TRANSFORM
_TRANSFORM_SAMPLINGRATIOS.containing_type = _TRANSFORM
_TRANSFORM_RELATIONSHIPSPEC.containing_type = _TRANSFORM
_TRANSFORM_SELECTSQL_ALIASEDQUERIES.fields_by_name['aliased_query'].message_type = _TRANSFORM_SELECTSQL_ALIASEDQUERY
_TRANSFORM_SELECTSQL_ALIASEDQUERIES.containing_type = _TRANSFORM_SELECTSQL
_TRANSFORM_SELECTSQL_ALIASEDQUERY.fields_by_name['path'].message_type = sarus__data__spec_dot_protobuf_dot_path__pb2._PATH
_TRANSFORM_SELECTSQL_ALIASEDQUERY.containing_type = _TRANSFORM_SELECTSQL
_TRANSFORM_SELECTSQL.fields_by_name['aliased_queries'].message_type = _TRANSFORM_SELECTSQL_ALIASEDQUERIES
_TRANSFORM_SELECTSQL.fields_by_name['sql_dialect'].enum_type = _TRANSFORM_SELECTSQL_SQLDIALECT
_TRANSFORM_SELECTSQL.containing_type = _TRANSFORM
_TRANSFORM_SELECTSQL_SQLDIALECT.containing_type = _TRANSFORM_SELECTSQL
_TRANSFORM_SELECTSQL.oneofs_by_name['select'].fields.append(
  _TRANSFORM_SELECTSQL.fields_by_name['query'])
_TRANSFORM_SELECTSQL.fields_by_name['query'].containing_oneof = _TRANSFORM_SELECTSQL.oneofs_by_name['select']
_TRANSFORM_SELECTSQL.oneofs_by_name['select'].fields.append(
  _TRANSFORM_SELECTSQL.fields_by_name['aliased_queries'])
_TRANSFORM_SELECTSQL.fields_by_name['aliased_queries'].containing_oneof = _TRANSFORM_SELECTSQL.oneofs_by_name['select']
_TRANSFORM_EXTRACT.containing_type = _TRANSFORM
_TRANSFORM.fields_by_name['spec'].message_type = _TRANSFORM_SPEC
_TRANSFORM.fields_by_name['properties'].message_type = _TRANSFORM_PROPERTIESENTRY
DESCRIPTOR.message_types_by_name['Transform'] = _TRANSFORM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Transform = _reflection.GeneratedProtocolMessageType('Transform', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_PROPERTIESENTRY,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.PropertiesEntry)
    })
  ,

  'Spec' : _reflection.GeneratedProtocolMessageType('Spec', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_SPEC,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Spec)
    })
  ,

  'External' : _reflection.GeneratedProtocolMessageType('External', (_message.Message,), {

    'OpIdentifier' : _reflection.GeneratedProtocolMessageType('OpIdentifier', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_EXTERNAL_OPIDENTIFIER,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.External.OpIdentifier)
      })
    ,

    'Std' : _reflection.GeneratedProtocolMessageType('Std', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_EXTERNAL_STD,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.External.Std)
      })
    ,

    'Pandas' : _reflection.GeneratedProtocolMessageType('Pandas', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_EXTERNAL_PANDAS,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.External.Pandas)
      })
    ,

    'Numpy' : _reflection.GeneratedProtocolMessageType('Numpy', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_EXTERNAL_NUMPY,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.External.Numpy)
      })
    ,

    'Tensorflow' : _reflection.GeneratedProtocolMessageType('Tensorflow', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_EXTERNAL_TENSORFLOW,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.External.Tensorflow)
      })
    ,

    'Sklearn' : _reflection.GeneratedProtocolMessageType('Sklearn', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_EXTERNAL_SKLEARN,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.External.Sklearn)
      })
    ,

    'PandasProfiling' : _reflection.GeneratedProtocolMessageType('PandasProfiling', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_EXTERNAL_PANDASPROFILING,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.External.PandasProfiling)
      })
    ,

    'XGBoost' : _reflection.GeneratedProtocolMessageType('XGBoost', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_EXTERNAL_XGBOOST,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.External.XGBoost)
      })
    ,

    'Skopt' : _reflection.GeneratedProtocolMessageType('Skopt', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_EXTERNAL_SKOPT,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.External.Skopt)
      })
    ,

    'Imblearn' : _reflection.GeneratedProtocolMessageType('Imblearn', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_EXTERNAL_IMBLEARN,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.External.Imblearn)
      })
    ,
    'DESCRIPTOR' : _TRANSFORM_EXTERNAL,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.External)
    })
  ,

  'Identity' : _reflection.GeneratedProtocolMessageType('Identity', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_IDENTITY,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Identity)
    })
  ,

  'Variable' : _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_VARIABLE,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Variable)
    })
  ,

  'Composed' : _reflection.GeneratedProtocolMessageType('Composed', (_message.Message,), {

    'NamedArgumentsEntry' : _reflection.GeneratedProtocolMessageType('NamedArgumentsEntry', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_COMPOSED_NAMEDARGUMENTSENTRY,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.Composed.NamedArgumentsEntry)
      })
    ,
    'DESCRIPTOR' : _TRANSFORM_COMPOSED,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Composed)
    })
  ,

  'Project' : _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_PROJECT,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Project)
    })
  ,

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_FILTER,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Filter)
    })
  ,

  'Shuffle' : _reflection.GeneratedProtocolMessageType('Shuffle', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_SHUFFLE,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Shuffle)
    })
  ,

  'Join' : _reflection.GeneratedProtocolMessageType('Join', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_JOIN,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Join)
    })
  ,

  'Cast' : _reflection.GeneratedProtocolMessageType('Cast', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_CAST,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Cast)
    })
  ,

  'Sample' : _reflection.GeneratedProtocolMessageType('Sample', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_SAMPLE,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Sample)
    })
  ,

  'SchemaInference' : _reflection.GeneratedProtocolMessageType('SchemaInference', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_SCHEMAINFERENCE,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.SchemaInference)
    })
  ,

  'GroupBy' : _reflection.GeneratedProtocolMessageType('GroupBy', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_GROUPBY,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.GroupBy)
    })
  ,

  'Synthetic' : _reflection.GeneratedProtocolMessageType('Synthetic', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_SYNTHETIC,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Synthetic)
    })
  ,

  'UserSettings' : _reflection.GeneratedProtocolMessageType('UserSettings', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_USERSETTINGS,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.UserSettings)
    })
  ,

  'AutomaticUserSettings' : _reflection.GeneratedProtocolMessageType('AutomaticUserSettings', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_AUTOMATICUSERSETTINGS,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.AutomaticUserSettings)
    })
  ,

  'Protect' : _reflection.GeneratedProtocolMessageType('Protect', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_PROTECT,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Protect)
    })
  ,

  'Transcode' : _reflection.GeneratedProtocolMessageType('Transcode', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_TRANSCODE,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Transcode)
    })
  ,

  'InverseTranscode' : _reflection.GeneratedProtocolMessageType('InverseTranscode', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_INVERSETRANSCODE,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.InverseTranscode)
    })
  ,

  'DifferentiatedSample' : _reflection.GeneratedProtocolMessageType('DifferentiatedSample', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_DIFFERENTIATEDSAMPLE,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.DifferentiatedSample)
    })
  ,

  'ProtectedPaths' : _reflection.GeneratedProtocolMessageType('ProtectedPaths', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_PROTECTEDPATHS,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.ProtectedPaths)
    })
  ,

  'PublicPaths' : _reflection.GeneratedProtocolMessageType('PublicPaths', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_PUBLICPATHS,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.PublicPaths)
    })
  ,

  'GetItem' : _reflection.GeneratedProtocolMessageType('GetItem', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_GETITEM,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.GetItem)
    })
  ,

  'AssignBudget' : _reflection.GeneratedProtocolMessageType('AssignBudget', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_ASSIGNBUDGET,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.AssignBudget)
    })
  ,

  'AutomaticBudget' : _reflection.GeneratedProtocolMessageType('AutomaticBudget', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_AUTOMATICBUDGET,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.AutomaticBudget)
    })
  ,

  'AttributesBudget' : _reflection.GeneratedProtocolMessageType('AttributesBudget', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_ATTRIBUTESBUDGET,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.AttributesBudget)
    })
  ,

  'SDBudget' : _reflection.GeneratedProtocolMessageType('SDBudget', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_SDBUDGET,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.SDBudget)
    })
  ,

  'DeriveSeed' : _reflection.GeneratedProtocolMessageType('DeriveSeed', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_DERIVESEED,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.DeriveSeed)
    })
  ,

  'GroupByPE' : _reflection.GeneratedProtocolMessageType('GroupByPE', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_GROUPBYPE,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.GroupByPE)
    })
  ,

  'SamplingRatios' : _reflection.GeneratedProtocolMessageType('SamplingRatios', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_SAMPLINGRATIOS,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.SamplingRatios)
    })
  ,

  'RelationshipSpec' : _reflection.GeneratedProtocolMessageType('RelationshipSpec', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_RELATIONSHIPSPEC,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.RelationshipSpec)
    })
  ,

  'SelectSql' : _reflection.GeneratedProtocolMessageType('SelectSql', (_message.Message,), {

    'AliasedQueries' : _reflection.GeneratedProtocolMessageType('AliasedQueries', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_SELECTSQL_ALIASEDQUERIES,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.SelectSql.AliasedQueries)
      })
    ,

    'AliasedQuery' : _reflection.GeneratedProtocolMessageType('AliasedQuery', (_message.Message,), {
      'DESCRIPTOR' : _TRANSFORM_SELECTSQL_ALIASEDQUERY,
      '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
      # @@protoc_insertion_point(class_scope:Transform.SelectSql.AliasedQuery)
      })
    ,
    'DESCRIPTOR' : _TRANSFORM_SELECTSQL,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.SelectSql)
    })
  ,

  'Extract' : _reflection.GeneratedProtocolMessageType('Extract', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFORM_EXTRACT,
    '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
    # @@protoc_insertion_point(class_scope:Transform.Extract)
    })
  ,
  'DESCRIPTOR' : _TRANSFORM,
  '__module__' : 'sarus_data_spec.protobuf.transform_pb2'
  # @@protoc_insertion_point(class_scope:Transform)
  })
_sym_db.RegisterMessage(Transform)
_sym_db.RegisterMessage(Transform.PropertiesEntry)
_sym_db.RegisterMessage(Transform.Spec)
_sym_db.RegisterMessage(Transform.External)
_sym_db.RegisterMessage(Transform.External.OpIdentifier)
_sym_db.RegisterMessage(Transform.External.Std)
_sym_db.RegisterMessage(Transform.External.Pandas)
_sym_db.RegisterMessage(Transform.External.Numpy)
_sym_db.RegisterMessage(Transform.External.Tensorflow)
_sym_db.RegisterMessage(Transform.External.Sklearn)
_sym_db.RegisterMessage(Transform.External.PandasProfiling)
_sym_db.RegisterMessage(Transform.External.XGBoost)
_sym_db.RegisterMessage(Transform.External.Skopt)
_sym_db.RegisterMessage(Transform.External.Imblearn)
_sym_db.RegisterMessage(Transform.Identity)
_sym_db.RegisterMessage(Transform.Variable)
_sym_db.RegisterMessage(Transform.Composed)
_sym_db.RegisterMessage(Transform.Composed.NamedArgumentsEntry)
_sym_db.RegisterMessage(Transform.Project)
_sym_db.RegisterMessage(Transform.Filter)
_sym_db.RegisterMessage(Transform.Shuffle)
_sym_db.RegisterMessage(Transform.Join)
_sym_db.RegisterMessage(Transform.Cast)
_sym_db.RegisterMessage(Transform.Sample)
_sym_db.RegisterMessage(Transform.SchemaInference)
_sym_db.RegisterMessage(Transform.GroupBy)
_sym_db.RegisterMessage(Transform.Synthetic)
_sym_db.RegisterMessage(Transform.UserSettings)
_sym_db.RegisterMessage(Transform.AutomaticUserSettings)
_sym_db.RegisterMessage(Transform.Protect)
_sym_db.RegisterMessage(Transform.Transcode)
_sym_db.RegisterMessage(Transform.InverseTranscode)
_sym_db.RegisterMessage(Transform.DifferentiatedSample)
_sym_db.RegisterMessage(Transform.ProtectedPaths)
_sym_db.RegisterMessage(Transform.PublicPaths)
_sym_db.RegisterMessage(Transform.GetItem)
_sym_db.RegisterMessage(Transform.AssignBudget)
_sym_db.RegisterMessage(Transform.AutomaticBudget)
_sym_db.RegisterMessage(Transform.AttributesBudget)
_sym_db.RegisterMessage(Transform.SDBudget)
_sym_db.RegisterMessage(Transform.DeriveSeed)
_sym_db.RegisterMessage(Transform.GroupByPE)
_sym_db.RegisterMessage(Transform.SamplingRatios)
_sym_db.RegisterMessage(Transform.RelationshipSpec)
_sym_db.RegisterMessage(Transform.SelectSql)
_sym_db.RegisterMessage(Transform.SelectSql.AliasedQueries)
_sym_db.RegisterMessage(Transform.SelectSql.AliasedQuery)
_sym_db.RegisterMessage(Transform.Extract)


_TRANSFORM_PROPERTIESENTRY._options = None
_TRANSFORM_COMPOSED_NAMEDARGUMENTSENTRY._options = None
# @@protoc_insertion_point(module_scope)



import logging
import traceback
import typing as t

import pyarrow as pa
import pyarrow.parquet as pq

from sarus_data_spec import typing as st
from sarus_data_spec.constants import ARROW_TASK
from sarus_data_spec.dataset import Dataset
from sarus_data_spec.manager.asyncio.base import ErrorCatchingAsyncIterator
from sarus_data_spec.manager.asyncio.utils import async_iter
from sarus_data_spec.manager.asyncio.worker.caching_computation import (
    ToParquetComputation,
)
from sarus_data_spec.manager.asyncio.worker.worker_computation import (
    TypedWorkerManager,
    WorkerComputation,
)
import sarus_data_spec.status as stt

logger = logging.getLogger(__name__)


class ToArrowComputation(WorkerComputation[t.AsyncIterator[pa.RecordBatch]]):
    task_name = ARROW_TASK

    def __init__(
        self,
        manager: TypedWorkerManager,
        parquet_computation: ToParquetComputation,
    ) -> None:
        super().__init__(manager)
        self.parquet_computation = parquet_computation

    async def prepare(self, dataspec: st.DataSpec) -> None:
        try:
            logger.debug(f'STARTED ARROW {dataspec.uuid()}')
            # Only prepare parents since calling `to_arrow` will require the
            # computation of the scalars in the ancestry.
            dataset = t.cast(st.Dataset, dataspec)

            if self.manager().is_cached(dataspec):
                await self.parquet_computation.task_result(dataspec)

            else:
                await self.manager().async_prepare_parents(dataset)
                if dataset.is_source():
                    await self.manager().async_schema(dataset)
                elif dataset.is_transformed():
                    transform = dataset.transform()
                    if not transform.is_external():
                        await self.manager().async_schema(dataset)
        except stt.DataSpecErrorStatus as exception:
            stt.error(
                dataspec=dataspec,
                manager=self.manager(),
                task=self.task_name,
                properties={
                    "message": traceback.format_exc(),
                    'relaunch': str(exception.relaunch),
                },
            )
            raise
        except Exception:
            stt.error(
                dataspec=dataspec,
                manager=self.manager(),
                task=self.task_name,
                properties={
                    "message": traceback.format_exc(),
                    'relaunch': str(False),
                },
            )
            raise stt.DataSpecErrorStatus((False, traceback.format_exc()))
        else:
            logger.debug(f'FINISHED ARROW {dataspec.uuid()}')
            stt.ready(
                dataspec=dataspec,
                manager=self.manager(),
                task=self.task_name,
            )

    async def read_ready_result(
        self,
        dataspec: st.DataSpec,
        properties: t.Mapping[str, str],
        **kwargs: t.Any,
    ) -> t.AsyncIterator[pa.RecordBatch]:
        """Returns the iterator"""
        batch_size = kwargs['batch_size']

        if self.manager().is_cached(dataspec):
            status = self.parquet_computation.status(dataspec)
            assert status
            stage = status.task(self.parquet_computation.task_name)
            assert stage
            assert stage.ready()
            cache_path = await self.parquet_computation.read_ready_result(
                dataspec, stage.properties()
            )
            try:
                ait = async_iter(
                    pq.read_table(source=cache_path).to_batches(
                        max_chunksize=batch_size
                    )
                )
            except Exception as e:
                stt.error(
                    dataspec=dataspec,
                    manager=self.manager(),
                    task=self.task_name,
                    properties={
                        "message": traceback.format_exc(),
                        'relaunch': str(True),
                    },
                )
                stt.error(
                    dataspec=dataspec,
                    manager=self.manager(),
                    task=self.parquet_computation.task_name,
                    properties={
                        "message": traceback.format_exc(),
                        'relaunch': str(True),
                    },
                )

                raise stt.DataSpecErrorStatus(
                    (True, traceback.format_exc())
                ) from e
        else:
            ait = await self.manager().async_to_arrow_op(
                dataset=t.cast(Dataset, dataspec), batch_size=batch_size
            )
        return ErrorCatchingAsyncIterator(ait, dataspec, self)
